@@ -27,8 +27,8 @@
 #' \tabular{ll}{
 #' Package: \tab RSDA\cr
 #' Type: \tab Package\cr
-#' Version: \tab 3.0.12\cr
-#' Date: \tab 2022-07-04\cr
+#' Version: \tab 3.0.13\cr
+#' Date: \tab 2022-07-15\cr
 #' License: \tab GPL (>=2)\cr
 #' }
 #' Most of the function of the package stars from a symbolic data table that can be store in
@@ -83,5 +83,6 @@ NULL
 utils::globalVariables(c(
   "to", "from", "interval", "n", "prob", "pca.max", "N", "M",
   "<<-", ".", "do", "quo", "concept","C1","C1.1","C2","C2.1","var.name","cat.name","symindiv","Variables",
-  "value","Individuals","pos.var",":=","real.value"
+  "value","Individuals","pos.var",":=","real.value","V1", "V2",
+  "group", "xmax", "xmin", "ymax", "ymin"
 ))
